@@ -17,8 +17,7 @@ class Metadata():
         
         if Logger.log is None:
             Logger('Metadata')
-        if os.environ['LOG_LEVEL']=='DEBUG':
-            Logger.log.debug('Initializing Metadata %s,%s,%s ...' % (user,name,mode))
+        
         self.user = user
         
         self.s3read = False
@@ -35,15 +34,11 @@ class Metadata():
 
         self.name = name
         self.xls = {}
-        self.static = pd.DataFrame([])        
-        self.symbols = pd.DataFrame([],dtype=str)
-        self.series = pd.Series([],dtype=str)
+        self.static = pd.DataFrame([])                
         self.fpath = Path(os.environ['DATABASE_FOLDER']) / user
 
         self.pathxls = self.fpath /  ('Metadata/'+name+'.xlsx')
-        self.pathpkl = self.fpath /  ('Metadata/'+name+'.pkl')
-        self.pathsymbols = self.fpath /  ('Metadata/'+name+'_SYMBOLS.pkl')
-        self.pathseries = self.fpath /  ('Metadata/'+name+'_SERIES.pkl')
+        self.pathpkl = self.fpath /  ('Metadata/'+name+'.pkl')        
 
         if (self.s3read):            
             S3SyncDownloadMetadata(self.pathpkl,self.name)
@@ -58,30 +53,23 @@ class Metadata():
         
         if readpkl:
             tini = time.time()
-            if os.environ['LOG_LEVEL']=='DEBUG':
-                Logger.log.debug('Loading metadata pkl ' + name + ' ...')
+
             self.static = pd.read_pickle(self.pathpkl)
             self.static = self.static.sort_index()
-            if self.pathsymbols.is_file():
-                self.symbols = pd.read_pickle(self.pathsymbols)
-                self.symbols = self.symbols.sort_index()
-            if self.pathseries.is_file():
-                self.series = pd.read_pickle(self.pathseries)
-                self.series = self.series.sort_index()
+
             if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Loading metadata pkl %s %.2f done!' % (name,time.time()-tini))
 
         elif readxlsx:
             tini = time.time()
-            Logger.log.debug('Loading metadata xlsx ' + name + ' ...')
+            
             self.xls = pd.read_excel(self.pathxls,sheet_name=None)
-            self.static = self.xls['static']
-            if 'symbols' in self.xls.keys():
-                self.symbols = self.xls['symbols']
+            if 'static' in self.xls:
+                self.static = self.xls['static']
+
             if not self.static.empty:
                 self.static = self.static.set_index(self.static.columns[0])
-            if not self.symbols.empty:
-                self.symbols = self.symbols.set_index(self.symbols.columns[0])
+
             if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Loading metadata xlsx %s %.2f done!' % (name,time.time()-tini))
         
@@ -98,11 +86,12 @@ class Metadata():
         # save excel first so that last modified
         # timestamp is older        
         if save_excel:
-            writer = pd.ExcelWriter(self.pathxls, engine='xlsxwriter')            
-            self.static.to_excel(writer,sheet_name='static')        
-            if not self.symbols.empty:
-                self.symbols.to_excel(writer,sheet_name='symbols')
-            writer.save()        
+            with open(self.pathxls, 'wb') as f:
+                writer = pd.ExcelWriter(f, engine='xlsxwriter')            
+                self.static.to_excel(writer,sheet_name='static')
+                writer.save()                
+                f.flush()
+
             if self.s3write:
                 S3Upload(self.pathxls)
 
@@ -113,25 +102,8 @@ class Metadata():
         if self.s3write:
             S3Upload(self.pathpkl)
 
-        if not self.symbols.empty:
-            with open(self.pathsymbols, 'wb') as f:
-                self.symbols.to_pickle(f)
-                f.flush()
-
-            if self.s3write:
-                S3Upload(self.pathsymbols)
-
-        if not self.series.empty:
-            with open(self.pathseries, 'wb') as f:
-                self.series.to_pickle(f)
-                f.flush()
-                
-            if self.s3write:
-                S3Upload(self.pathseries)
-
         if os.environ['LOG_LEVEL']=='DEBUG':
-            Logger.log.debug('Saving metadata ' + self.name + \
-                ' %.2f done!' % (time.time()-tini))
+            Logger.log.debug('Saving metadata ' + self.name + ' %.2f done!' % (time.time()-tini))
     
     def mergeUpdate(self,newdf):
         ddidx = newdf.index.duplicated()
