@@ -47,7 +47,8 @@ def S3SyncDownloadTimeSeries(path,shm_name):
         for obj_s in bucket.objects.filter(Prefix=shm_name+'/')])
     idx = ['shm_info.json' not in f for f in files]
     files = files[idx]
-    result = io_bound_process(S3DownloadThread,files,[s3])
+    if len(files)>0:
+        result = io_bound_process(S3DownloadThread,files,[s3])
 
     if success:
         if os.environ['LOG_LEVEL']=='DEBUG':
@@ -59,8 +60,6 @@ def S3SyncDownloadTimeSeries(path,shm_name):
 def S3SyncDownloadMetadata(pathpkl,name):    
     
     success = S3Download(str(pathpkl))
-    success = (success) & (S3Download(str(pathpkl).replace('.pkl','.xlsx')))
-    success = (success) & (S3Download(str(pathpkl).replace('.pkl','_SYMBOLS.pkl')))
     
     if success:
         if os.environ['LOG_LEVEL']=='DEBUG':
@@ -83,19 +82,25 @@ def S3Download(local_path,s3=None):
         remote_mtime = obj.last_modified.timestamp()
         if 'mtime' in obj.metadata:
             remote_mtime = float(obj.metadata['mtime'])
-        remote_size = obj.content_length
+        #remote_size = obj.content_length
+    except:
+        # remote file dont exist 
+        return True
+    
+    if os.path.isfile(str(local_path)):
         # local mtime size
         local_mtime = datetime.utcfromtimestamp(os.path.getmtime(local_path)).timestamp()
-        local_size = os.path.getsize(local_path)
+        #local_size = os.path.getsize(local_path)
         #compare
         isnewer = remote_mtime>local_mtime
-        ischg = remote_size!=local_size
-    except:
-        # file dont exist
-        return True
+        #ischg = remote_size!=local_size
+    else:
+        # local file dont exist 
+        isnewer = True
+        #ischg = True
 
-    if isnewer or ischg:
-        try:            
+    if isnewer:
+        try:
             obj.download_file(local_path)
             # update modification time
             remote_mtime_dt = datetime.fromtimestamp(remote_mtime)
