@@ -299,12 +299,13 @@ class SharedDataTimeSeries:
                         (shm_name,100*(n/nfiles),time.time()-tini))
 
     def read_multithread(self,file_paths):
-        # create a thread pool
-        with ThreadPoolExecutor(file_paths.shape[0]) as exe:
-            futures = [exe.submit(self.read_thread, fpath) \
-                for fpath in file_paths]
-            # collect data
-            data = [future.result() for future in futures]
+        if file_paths.shape[0]>0:
+            # create a thread pool
+            with ThreadPoolExecutor(file_paths.shape[0]) as exe:
+                futures = [exe.submit(self.read_thread, fpath) \
+                    for fpath in file_paths]
+                # collect data
+                data = [future.result() for future in futures]
         
     def read_thread(self,fpath):
         arr = np.load(str(fpath),mmap_mode='r')
@@ -354,12 +355,13 @@ class SharedDataTimeSeries:
                 (shm_name,startdatestr,100*cy/ny,time.time()-tini))        
             
     def write_multithread(self, years, path):
-        # create a thread pool
-        with ThreadPoolExecutor(years.shape[0]) as exe:
-            futures = [exe.submit(self.write_thread, year, path) \
-                for year in years]
-            # collect data
-            data = [future.result() for future in futures]
+        if years.shape[0]>0:
+            # create a thread pool
+            with ThreadPoolExecutor(years.shape[0]) as exe:
+                futures = [exe.submit(self.write_thread, year, path) \
+                    for year in years]
+                # collect data
+                data = [future.result() for future in futures]
         
     def write_thread(self,y, path):
         idx = self.data.index[self.data.index.year==y]
